<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://themify.me/
 * @since      1.0.0
 *
 * @package    Tbp
 * @subpackage Tbp/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Tbp
 * @subpackage Tbp/includes
 * @author     Themify <themify@themify.me>
 */
final class Tbp {

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	const PLUGIN_NAME='tbp';
	
	
	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected static $version;

	private function __construct() {

	}

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public static function run() {
	    if (class_exists( 'Themify_Builder' ) ) {
		    self::$version = current(get_file_data( TBP_DIR.'themify-builder-pro.php', array( 'Version') ));
		    self::i18n();
		    self::register_cpt();
		    self::load_dependencies();
                    Tbp_Dynamic_Content::run();
                    Tbp_Dynamic_Query::run();
                    if ( class_exists('Tbp_Admin') ) {
                        Tbp_Admin::run();
                    }
                    if(themify_is_ajax() || !is_admin()){
                        Tbp_Public::run();
                    }
                    add_action('themify_builder_setup_modules',array(__CLASS__,'register_module'));

                    self::plugins_compatibility();
	    }
	}
	
	public static function register_cpt(){
	    /**
	    * The class responsible for themes functions.
	    */
	   require_once TBP_DIR. 'includes/class-tbp-themes.php';
	   /**
	    * The class responsible for templates functions.
	    */
	   require_once TBP_DIR. 'includes/class-tbp-templates.php';
	}

	public static function register_module() {
            if(method_exists('Themify_Builder_Model', 'add_module')){
                $modules=array(
                    'acf-repeater',
                    'ptb-repeater',
                    'add-to-cart',
                    'advanced-posts',
                    'advanced-products',
                    'archive-description',
                    'archive-image',
                    'archive-posts',
                    'archive-products',
                    'archive-title',
                    'author-info',
                    'breadcrumbs',
                    'cart-icon',
                    'comments',
                    'featured-image',
                    'post-content',
                    'post-meta',
                    'post-navigation',
                    'post-title',
                    'product-description',
                    'product-image',
                    'product-meta',
                    'product-price',
                    'product-rating',
                    'product-reviews',
                    'product-stock-status',
                    'product-taxonomy',
                    'product-title',
                    'related-posts',
                    'related-products',
                    'search-form',
                    'site-logo',
                    'site-tagline',
		    'stats',
		    'taxonomy',
                    'upsell-products',
                    'wc-notices',
                    'woocommerce-breadcrumb',
                    'woocommerce-hook',
		    'readtime',
                );
                $dir=TBP_DIR . 'modules/module-';
                foreach($modules as $m){
                    Themify_Builder_Model::add_module($dir.$m.'.php' );
                }
            }
            else{
                Themify_Builder_Model::register_directory('templates', TBP_DIR . 'templates');
                Themify_Builder_Model::register_directory('modules', TBP_DIR . 'modules');
            }
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Tbp_Admin. Defines all hooks for the admin area.
	 * - Tbp_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private static function load_dependencies() {
		
		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */

		/**
		 * The class responsible for various functions.
		 */
		require_once TBP_DIR. 'includes/class-tbp-utils.php';
		
		
		/**
		 * Handles Dynamic Content feature.
		 */
		require_once TBP_DIR. 'includes/class-tbp-dynamic-content.php';

		require_once TBP_DIR. 'includes/class-tbp-dynamic-query.php';

		if(is_admin() || themify_is_ajax()){
		    /**
		     * The class responsible for pointer functions.
		     */
		    require_once TBP_DIR. 'admin/class-tbp-import-export.php';

			/* load Term Cover feature in Themify framework */
			add_theme_support( 'themify-term-cover' );
		}
		
		if(Tbp_Utils::has_access()){
			/**
			 * The class responsible for defining all actions that occur in the admin area.
			 */
			require_once TBP_DIR. 'admin/class-tbp-admin.php';
		}
		
		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once TBP_DIR. 'public/class-tbp-public.php';

	}



	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public static function get_plugin_name() {
		return self::PLUGIN_NAME;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public static function get_version() {
		return self::$version;
	}
	

	/**
	 * Load compatibility patches for Pro plugin
	 */
	private static function plugins_compatibility(){
		$plugins = array(
			'wooVariationSwatches' => 'woo-variation-swatches-pro/woo-variation-swatches-pro.php',
			'wooProductFeeds' => 'woocommerce-product-feeds/woocommerce-gpf.php',
			'polylang' => 'polylang/polylang.php',
			'ptb' => 'themify-ptb/post-type-builder.php',
			'ptbRelations' => 'themify-ptb-relation/themify-ptb-relation.php',
			'acf' => 'advanced-custom-fields/acf.php',
			'acfPro' => 'advanced-custom-fields-pro/acf.php',
			'mapsPro' => 'builder-maps-pro/init.php',
			'ptbSubmission' => 'themify-ptb-submissions/themify-ptb-submissions.php',
			'wcPaypalPayments' => 'woocommerce-paypal-payments/woocommerce-paypal-payments.php',
			'themifyEventPost' => 'themify-event-post/themify-event-post.php',
		);
		foreach ( $plugins as $plugin => $active_check ) {
			if ( Themify_Builder_Model::is_plugin_active( $active_check ) ) {
				include( TBP_DIR . 'includes/integration/' . $plugin . '.php' );
				$classname = "Themify_Builder_Plugin_Compat_{$plugin}";
				$classname::init();
			}
		}
		unset( $plugins );
	}

	/**
	 * Load language files
	 */
	public static function i18n() {
		load_plugin_textdomain( 'tbp', false, 'themify-builder-pro/languages' );
	}
}